risorchart

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 29, 2026 License: BSD-3-Clause Imports: 16 Imported by: 0

Documentation

Index

Constants

const BarChartType object.Type = "chart.barchart"

Variables

This section is empty.

Functions

This section is empty.

Types

type BarChart

type BarChart struct {
	// contains filtered or unexported fields
}

func NewBarChart

func NewBarChart(title, ylabel string, labels []string, values []float64) (*BarChart, error)

NewBarChart creates a new bar chart widget with the given title, y-axis label, x-axis labels, and values. Returns an error if the chart cannot be created (e.g., mismatched labels and values lengths).

func (*BarChart) Attrs

func (r *BarChart) Attrs() []object.AttrSpec

func (*BarChart) CanvasObject

func (obj *BarChart) CanvasObject() fyne.CanvasObject

func (*BarChart) Equals

func (r *BarChart) Equals(other object.Object) bool

func (*BarChart) GetAttr

func (g *BarChart) GetAttr(name string) (object.Object, bool)

func (*BarChart) Inspect

func (r *BarChart) Inspect() string

func (*BarChart) Interface

func (r *BarChart) Interface() interface{}

func (*BarChart) IsTruthy

func (r *BarChart) IsTruthy() bool

func (*BarChart) MarshalJSON

func (r *BarChart) MarshalJSON() ([]byte, error)

func (*BarChart) RunOperation

func (r *BarChart) RunOperation(opType op.BinaryOpType, right object.Object) (object.Object, error)

func (*BarChart) SetAttr

func (r *BarChart) SetAttr(name string, value object.Object) error

func (*BarChart) Type

func (r *BarChart) Type() object.Type

Jump to