Documentation
¶
Index ¶
- Constants
- type BarChart
- func (r *BarChart) Attrs() []object.AttrSpec
- func (obj *BarChart) CanvasObject() fyne.CanvasObject
- func (r *BarChart) Equals(other object.Object) bool
- func (g *BarChart) GetAttr(name string) (object.Object, bool)
- func (r *BarChart) Inspect() string
- func (r *BarChart) Interface() interface{}
- func (r *BarChart) IsTruthy() bool
- func (r *BarChart) MarshalJSON() ([]byte, error)
- func (r *BarChart) RunOperation(opType op.BinaryOpType, right object.Object) (object.Object, error)
- func (r *BarChart) SetAttr(name string, value object.Object) error
- func (r *BarChart) Type() object.Type
Constants ¶
const BarChartType object.Type = "chart.barchart"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BarChart ¶
type BarChart struct {
// contains filtered or unexported fields
}
func NewBarChart ¶
NewBarChart creates a new bar chart widget with the given title, y-axis label, x-axis labels, and values. Returns an error if the chart cannot be created (e.g., mismatched labels and values lengths).
func (*BarChart) CanvasObject ¶
func (obj *BarChart) CanvasObject() fyne.CanvasObject
func (*BarChart) MarshalJSON ¶
func (*BarChart) RunOperation ¶
Click to show internal directories.
Click to hide internal directories.